/**
 * @file
 *
 * Definitions for Bayes Network
 */
#ifndef BAYES_NETWORK_HPP
#define BAYES_NETWORK_HPP
#include <stdio.h>
#include <vector>

namespace mtpk {

/**
 * Bayes Network Class representing a set of variables and
 * conditional dependencies
 */
class BayesNet {};

} // namespace mtpk

#endif
